function projection = iCTF_Regular_2d_projection(projection,params,varargin)
%ICTF_REGULAR_2D_PROJECTION   Regular CTF correction for 2D projection
%
%
% SYNOPSIS:
%  projection = ICTF_REGULAR_2D_PROJECTION(projection,params,type,norders,lambda);
% 
% PARAMETERS:
%  projection: Input projection (xp,yp)
%  params:     set of microscope and acquisition parameters
%  type:       'Wiener', 'Phase'
%  norders:    order of the Fourier expansion of the filter
%  lambda:     Regularisation parameter for Wiener filter
% 
% OUTPUT:
%  projection:   
%
% Note: The convention used in [1] for the order (N) of the filter is 
% different than the one used here: N = norders*2+1
% 
% [1] L.M. Voortman et al., Ultram. 2012, In press, 10.1016/j.ultramic.2012.05.002.

% The Quantitative Imaging Group of the TU Delft has developed and is the 
% owner of the image processing routines distributed in this package, 
% hereafter called SOFTWARE.
% 
% The SOFTWARE is free for non-commercial use by students and staff in 
% universities or non-profit research institutes.
% 
% Redistribution of SOFTWARE or parts thereof in any form is not permitted.
% 
% This SOFTWARE is distributed in the hope that it will be useful, but 
% without any warranty; without even the implied warranty of 
% merchantability or fitness for a particular purpose.

stdargin = nargin - size(varargin,2);
if nargin == stdargin
   type = 'Phase';
   norders = Inf;
   lambda = 0;
end
if nargin == stdargin + 1
   type = varargin{1};
   norders = Inf;
   lambda = 0.1;
end
if nargin == stdargin + 2
   type = varargin{1};
   norders = varargin{2};
   lambda = 0.1;
end
if nargin >= stdargin + 3
   type = varargin{1};
   norders = varargin{2};
   lambda = varargin{3};
end

projection = dip_image(projection);

if size(projection,1) ~= size(projection,2)
    error('image must be square');
end

N = size(projection,1);

qx = xx(N,1,'freq');
qy = yy(1,N,'freq');

q2 = qx^2 + qy^2;

projection = ft(projection);

p2 = q2*N^2/params.fov^2;
W0 = -pi*params.lambda*params.df_estimated*p2 + pi/2*params.C_s*params.lambda^3*p2.^2;

filter = getFilter(W0,type,lambda,norders);

projection = filter.*projection;

%inverse fourier transform
projection = real(ift(projection));
