function stack = iCTF_Regular_2d_test(stack,params,varargin)
%ICTF_REGULAR_2D   Regular CTF correction for 2D projection
%
%
% SYNOPSIS:
%  stack = ICTF_REGULAR_2D(stack,params);
% 
% PARAMETERS:
%  stack:      Input stack (xp,angles,yp)
%  params:     Set of microscope and acquisition parameters
%  type:       'Wiener', 'Phase' 
%  lambda:     Regularisation parameter for Wiener filter
% 
% OUTPUT:
%  stack:   

stdargin = nargin - size(varargin,2);
if nargin == stdargin
   type = 'Phase';
   lambda = 0;
end
if nargin == stdargin + 1
   type = varargin{1};
   lambda = 0.1;
end
if nargin >= stdargin + 2
   type = varargin{1};
   lambda = varargin{2};
end

stack = dip_image(stack);

if ndims(stack) ~= 3
    error('stack should be 3D');
end
if size(stack,1) ~= size(stack,3)
    error('images should be square');
end

N = size(stack,1);
qx = xx(N,1,1,'freq');
qy = zz(1,1,N,'freq');

% FT in y direction
stack = dip_fouriertransform(stack,'forward',[1 0 1]);

p2 = (qx^2 + qy^2)*N^2/params.fov^2;
W0 = -pi*params.lambda*params.df_estimated*p2 + pi/2*params.C_s*params.lambda^3*p2.^2;
filter = getFilter(sin(W0),type,lambda);

stack = filter*stack;

% IFT in y direction
stack = real(dip_fouriertransform(stack,'inverse',[1 0 1]));
