function stack = iCTF_Tilt_2d(stack,angles,params,varargin)
%ICTF_TILT_2D   Tilted CTF correction for 2D projection
%
%
% SYNOPSIS:
%  stack = ICTF_TILT_2D(stack,angles,params);
% 
% PARAMETERS:
%  stack:      Input stack (xp,angles,yp)
%  angles:     Angles corresponding to sinogram
%  params:     set of microscope and acquisition parameters
%  type:       'Wiener', 'Phase'
%  norders:    order of the Fourier expansion of the filter
%  lambda:     Regularisation parameter for Wiener filter
% 
% OUTPUT:
%  stack:   
%
% Note: The convention used in [1] for the order (N) of the filter is 
% different than the one used here: N = norders*2+1
% 
% [1] L.M. Voortman et al., Ultram. 2012, In press, 10.1016/j.ultramic.2012.05.002.

% The Quantitative Imaging Group of the TU Delft has developed and is the 
% owner of the image processing routines distributed in this package, 
% hereafter called SOFTWARE.
% 
% The SOFTWARE is free for non-commercial use by students and staff in 
% universities or non-profit research institutes.
% 
% Redistribution of SOFTWARE or parts thereof in any form is not permitted.
% 
% This SOFTWARE is distributed in the hope that it will be useful, but 
% without any warranty; without even the implied warranty of 
% merchantability or fitness for a particular purpose.

stdargin = nargin - size(varargin,2);
if nargin == stdargin
   type = 'Phase';
   norders = 7;
   lambda = 0;
end
if nargin == stdargin + 1
   type = varargin{1};
   norders = 7;
   lambda = 0.1;
end
if nargin == stdargin + 2
   type = varargin{1};
   norders = varargin{2};
   lambda = 0.1;
end
if nargin >= stdargin + 3
   type = varargin{1};
   norders = varargin{2};
   lambda = varargin{3};
end

stack = dip_image(stack);

if ndims(stack) ~= 3
    error('stack should be 3D');
end
if size(stack,2) ~= numel(angles)
    error('number of angles does not match size of stack');
end

Ny = size(stack,3);
qy = yy(1,Ny,'freq');

% FT in y direction
stack = dip_fouriertransform(stack,'forward',[0 0 1]);

% iterate over y
for k = 0:Ny-1
    sinogram = squeeze(stack(:,:,k));
    
    sinogram = iCTF_Tilt_2d_sinogram(sinogram,qy(0,k),angles,params,type,norders,lambda);
    
    stack(:,:,k) = sinogram;
end

% IFT in y direction
stack = real(dip_fouriertransform(stack,'inverse',[0 0 1]));
