function sinogram = iCTF_Tilt_strip_1d(sinogram,angles,params,varargin)
%ICTF_TILT_1D   Tilted CTF correction for 1D projection
%
%
% SYNOPSIS:
%  sinogram = ICTF_TILT_1D(sinogram,angles,params,type,norders,lambda);
% 
% PARAMETERS:
%  sinogram:   Input projections (xp,angles)
%  angles:     Angles corresponding to sinogram
%  params:     set of microscope and acquisition parameters
%  type:       'Wiener', 'Phase' 
%  norders:    order of the Fourier expansion of the filter
%  lambda:     Regularisation parameter for Wiener filter
% 
% OUTPUT:
%  sinogram:   
%
% Note: The convention used in [1] for the order (N) of the filter is 
% different than the one used here: N = norders*2+1
% 
% [1] L.M. Voortman et al., Ultram. 2012, In press, 10.1016/j.ultramic.2012.05.002.

% The Quantitative Imaging Group of the TU Delft has developed and is the 
% owner of the image processing routines distributed in this package, 
% hereafter called SOFTWARE.
% 
% The SOFTWARE is free for non-commercial use by students and staff in 
% universities or non-profit research institutes.
% 
% Redistribution of SOFTWARE or parts thereof in any form is not permitted.
% 
% This SOFTWARE is distributed in the hope that it will be useful, but 
% without any warranty; without even the implied warranty of 
% merchantability or fitness for a particular purpose.

% This 'strip' based CTF correction only serves as a reference method. It is 
% extremely slow and is not representative of optimized strip based methods.

stdargin = nargin - size(varargin,2);
if nargin == stdargin
   type = 'Phase';
   norders = Inf;
   lambda = 0;
end
if nargin == stdargin + 1
   type = varargin{1};
   norders = Inf;
   lambda = 0.1;
end
if nargin == stdargin + 2
   type = varargin{1};
   norders = varargin{2};
   lambda = 0.1;
end
if nargin >= stdargin + 3
   type = varargin{1};
   norders = varargin{2};
   lambda = varargin{3};
end

sinogram = dip_image(sinogram);
N = size(sinogram,1);
nangles = length(angles);

%forward fourier transform
Sinogram = dip_fouriertransform(sinogram,'forward',[1 0]);

tangles = newim(1,nangles);
tangles(:) = tan(angles);

p2  = xx(N,1).^2./params.fov.^2;
for k = 1:nangles
    z  = yy(1,N,'freq')*params.fov*tangles(k-1);

    W0 = -pi*params.lambda*(params.df_estimated+z)*p2 + pi/2*params.C_s*params.lambda^3*p2.^2;
    filter = getFilter(W0,type,lambda,norders);

    tmp = real(dip_fouriertransform(filter*Sinogram(:,k-1),'inverse',[1 0]));
    sinogram(:,k-1) = tmp(xx(N,1)==yy(1,N));
end
