function slice = iFreqDomRadon_1d(sinogram,angles)
%IFREQDOMRADON_1D   Compute Inverse Radon transform in Frequency domain
%
%
% SYNOPSIS:
%  slice = IFREQDOMRADON_1D(sinogram,angles);
% 
% PARAMETERS:
%  siniogram: Input sinogram (x,a)
%  angles:    Angles at corresponding to the projections

% The Quantitative Imaging Group of the TU Delft has developed and is the 
% owner of the image processing routines distributed in this package, 
% hereafter called SOFTWARE.
% 
% The SOFTWARE is free for non-commercial use by students and staff in 
% universities or non-profit research institutes.
% 
% Redistribution of SOFTWARE or parts thereof in any form is not permitted.
% 
% This SOFTWARE is distributed in the hope that it will be useful, but 
% without any warranty; without even the implied warranty of 
% merchantability or fitness for a particular purpose.

% make sure input is dip_image
sinogram = dip_image(sinogram);
N = size(sinogram,1);

%inverse fourier transform
sinogram = dip_fouriertransform(sinogram,'forward',[1 0]);

% create set of frequency points
qx = double(xx(N,1,'freq'));
qy = zeros(size(qx));

q = zeros(2,N*length(angles));

for t = 1:length(angles);
    R = [cos(angles(t)) sin(angles(t));-sin(angles(t)) cos(angles(t))];
    
    q(:,(t-1)*N+1:t*N) = R*[qx; qy];
end
q = mod(q+1,2)-1;
q = dip_image(q);

% weight for points in freq dom.
weight = newim([N,1]);
weight(:) = 2*pi*abs(qx)*1/N/length(angles);
weight(ceil(N/2)) = pi*(1/N/2)^2/length(angles);

% compute NUFFT
slice = real(nufft_type1(reshape(sinogram*weight,N*length(angles)),im2array(q),[N N]));
