function volume = iFreqDomRadon_2d(stack,angles,varargin)
%IFREQDOMRADON_2D   Compute Inverse Radon transform in Frequency domain
%
%
% SYNOPSIS:
%  volume = IFREQDOMRADON_2D(stack,angles,Nz);
% 
% PARAMETERS:
%  stack:   Input stack (x,a,y)
%  angles:  Angles at which to compute the projections
%  Nz:      (optional) size in z direction
%
% OUTPUT:
%  volume:   Output volume (x,z,y)

% The Quantitative Imaging Group of the TU Delft has developed and is the 
% owner of the image processing routines distributed in this package, 
% hereafter called SOFTWARE.
% 
% The SOFTWARE is free for non-commercial use by students and staff in 
% universities or non-profit research institutes.
% 
% Redistribution of SOFTWARE or parts thereof in any form is not permitted.
% 
% This SOFTWARE is distributed in the hope that it will be useful, but 
% without any warranty; without even the implied warranty of 
% merchantability or fitness for a particular purpose.

stack = dip_image(stack);

if nargin == 3
   Nz = varargin{1};
else
   Nz = size(stack,1);
end

if ndims(stack) ~= 3
    error('stack should be 3D');
end

Nx = size(stack,1);
Ny = size(stack,3);
nangles = numel(angles);

if nangles ~= size(stack,2)
   error('2nd dimension of stack should match number of angles');
end

% allocate output memory
volume = newim(Nx,Nz,Ny);

% iterate over y
for k = 0:Ny-1
    sinogram = squeeze(stack(:,:,k));
    
    slice = iFreqDomRadon_1d(sinogram,angles);
    
    volume(:,:,k) = cut(slice,[Nx Nz]);
end

