%% 2D projections
clear;

% define some constants
Nx = 512;        % size of volume
Nz = Nx/4;       % size of volume
Ny = Nx;         % size of volume
Npart=32;        % size of particle volume
particle_r = 10; % size of particle
sigma = 0.7;     % blurring of particle
nparticles = 64; % number of particles

nangles = 140;   % number of angles

% the microscope parameters
params.C_s           = 2e-3;
params.df_estimated  = 1e-6;
params.lambda        = 2.5e-12;
params.fov           = 200e-9;
params.tiltAngle     = 70/180*pi;


% create spherical test particle
particle = -erfclip(rr(Npart,Npart,Npart),particle_r,sigma);
particle = stretch(particle,0,100,0,128);
particle = dip_image(particle,'uint8');

% allocate volume
volume=newim(Nx, Nz, Ny,'uint8');

% fill volume with particles at random locations
for k = 1:nparticles
    xloc = floor(rand*(Nx-Npart));
    zloc = floor(rand*(Nz-Npart));
    yloc = floor(rand*(Ny-Npart));
    volume(xloc:xloc+Npart-1,zloc:zloc+Npart-1,yloc:yloc+Npart-1)=volume(xloc:xloc+Npart-1,zloc:zloc+Npart-1,yloc:yloc+Npart-1)+particle;
end
clear particle sigma nparticles Npart xloc yloc zloc k

% the angles of the tilt-series
angles = linspace(-params.tiltAngle,params.tiltAngle,nangles);

% check the functions
stack = FreqDomRadon_2d(volume,angles);
stack_CTF = CTF_Regular_2d(stack,params);
stack_TCTF = CTF_Tilt_2d(stack,angles,params);
stack_3DCTF = CTF_TiltThick_2d(volume,angles,params);

% check per projection
projection = squeeze(stack(:,0,:));
projection_CTF = CTF_Regular_2d_projection(projection,params);
projection_TCTF = CTF_Tilt_2d_projection(projection,angles(1),params);


%% 1D projections
clear;

% define some constants
N = 4096;         % size of slice
Npart=64;         % size of particle slice
particle_r = 15;  % size of particle
nparticles = 128; % number of particles
sigma = 0.7;      % blurring of particle

nangles = 140;    % number of angles

% the microscope parameters
params.C_s           = 2e-3;
params.df_estimated  = 1e-6;
params.lambda        = 2.5e-12;
params.fov           = 300e-9;
params.tiltAngle     = 70/180*pi;

% create spherical test particle
particle = 38*(-erfclip(rr(Npart,Npart),particle_r,sigma)+particle_r + sigma/2)/sigma;

% allocate slice
slice=newim(N, N);

% fill slice with particles at random locations
for k = 1:nparticles
    r = N;
    while r > N/2-Npart/2;
        xloc = floor(rand*(N-Npart));
        yloc = floor(rand*(N-Npart));
        r = sqrt((xloc-N/2+Npart/2)^2 + (yloc-N/2+Npart/2)^2);
    end
    slice(xloc:xloc+Npart-1,yloc:yloc+Npart-1)=slice(xloc:xloc+Npart-1,yloc:yloc+Npart-1)+particle;
end
clear particle xloc yloc k

% the angles of the tilt-series
angles = linspace(-params.tiltAngle,params.tiltAngle,nangles);

% check the functions
sinogram = FreqDomRadon_1d(slice,angles);
sinogram_CTF = CTF_Regular_1d(sinogram,params);
sinogram_TCTF = CTF_Tilt_1d(sinogram,angles,params);
sinogram_3DCTF = CTF_TiltThick_1d(slice,angles,params);
