clear;

%% prepare the sample
N = 512;         % size of slice

slice=newim(N, N);

Npart = 60;
thickness = 4;
sigma = 0.7;      % blurring of particle

particle = (-erfclip(max(abs(xx(Npart,Npart)),abs(yy(Npart,Npart))-Npart/2+thickness),thickness/2,sigma)+thickness/2 + sigma/2)/sigma;

nparticles = max(1,round(N^2./Npart^2));
for k = 1:nparticles
    xloc = round(rand(1)*(N-Npart-1))+1;
    yloc = round(rand(1)*(N-Npart-1))+1;
    slice(xloc:xloc+Npart-1,yloc:yloc+Npart-1)=slice(xloc:xloc+Npart-1,yloc:yloc+Npart-1)+cut(rotation(particle,pi*rand(1)),[Npart,Npart]);
end

%% prepare the sample
% N = 512;         % size of slice
% 
% slice=newim(N, N);
% 
% particlers = [5 15 30 60];
% 
% bilayert = 13;
% bilayerlayert = 2;
% sigmabilayer = 1.4;
% 
% for n = 1:length(particlers)
%     % create spherical test particle
%     particle_r = particlers(n);   % size of particle
%     Npart = 4*particle_r; % size of particle slice
%     sigma = 0.7;      % blurring of particle
% 
%     shape = max(abs(xx(Npart,Npart)),abs(yy(Npart,Npart)));
% %     shape = rr(Npart,Npart);
% 
%     if particle_r <= bilayert/2
%         particle = 38*(-erfclip(shape,particle_r,sigma)+particle_r + sigma/2)/sigma;
%     elseif particle_r <= bilayert
%         particle = 38*(-erfclip(abs(shape-particle_r),bilayerlayert,sigmabilayer)+bilayerlayert+sigmabilayer/2)/sigmabilayer;
%     else
%         particle = 38*(-erfclip(abs(shape-particle_r),bilayerlayert,sigmabilayer)+bilayerlayert+sigmabilayer/2)/sigmabilayer + 38*(-erfclip(abs(shape-particle_r-bilayert),bilayerlayert,sigmabilayer)+bilayerlayert+sigmabilayer/2)/sigmabilayer;
%     end
%     pixperparticle = 35*sqrt(5*particle_r);
%     
%     nparticles = 4*max(1,round(N^2./pixperparticle^2));
%     for k = 1:nparticles
%         xloc = round(rand(1)*(N-Npart-1))+1;
%         yloc = round(rand(1)*(N-Npart-1))+1;
%         slice(xloc:xloc+Npart-1,yloc:yloc+Npart-1)=slice(xloc:xloc+Npart-1,yloc:yloc+Npart-1)+particle;
%     end
% end
% clear particle xloc yloc k margin nparticles particle_r sigma particlealpha particlers pixperparticle circler circlerr m n
% 
% 
%% do the CTF
tiltAngle = 10/180*pi;
pixelpitch = 1e-10;

% the microscope parameters
params.C_s           = 0;
params.df_estimated  = 2e-6;
params.Volt          = 200e3;
params.lambda        = wavlen(params.Volt);
params.fov           = N*pixelpitch;

nangles = 1;
angles = linspace(-tiltAngle,tiltAngle,nangles);
stack = zeros(N,N,nangles);

for k = 1:nangles
    stack(:,:,k) = double(CTF_Tilt_2d_projection(slice,angles(k),params))';
end

tom_mrcwrite(stack,'name','etomo/tiltedprojections.mrc');

%% do CTF correction using NUFFT
projection_iTCTF = zeros(N,N,nangles);
% projection_iCTF = zeros(N,N,nangles);

for k = 1:nangles
    projection = stack(:,:,k);
    projection = dip_image(projection');
    tic;
    projection_iTCTF(:,:,k) = double(iCTF_Tilt_2d_projection(projection,angles(k),params,'Phase',4))';
    toc;
%     projection_iCTF(:,:,k) = double(iCTF_Regular_2d_projection(projection,params,'Phase'))';
end

%% do imod stuff

fid = fopen('etomo/tiltedprojections.tlt','w');
fprintf(fid,'%7.2f\r\n',angles*180/pi);
fclose(fid);

fid = fopen('etomo/tiltedprojection_simple.defocus','w');
fprintf(fid,'1 %i 0 0 %.1f\r\n',nangles,-params.df_estimated*1e9);
fclose(fid);

cygcommand = sprintf(['ctfphaseflip'...
' -InputStack tiltedprojections.mrc'...
' -AngleFile tiltedprojections.tlt'...
' -OutputFileName tiltedprojections_ctfcorr.mrc'...
' -InvertTiltAngles'...
' -DefocusFile tiltedprojection_simple.defocus'...
' -Voltage %i'...
' -SphericalAberration %.1f'...
' -DefocusTol 1'...
' -PixelSize %.3f'...
' -AmplitudeContrast 0'...
' -InterpolationWidth 32'...
],params.Volt*1e-3,params.C_s*1e3,pixelpitch*1e9);


% run the command
tic;
cd etomo
dos(cygcommand);
cd ../
toc;

% read the result

slice_phaseflip = tom_mrcread('etomo/tiltedprojections_ctfcorr.mrc');
slice_phaseflip = slice_phaseflip.Value;

%% show the results

slice_phaseflip_mean = mean(slice_phaseflip(:));
slice_phaseflip = slice_phaseflip - slice_phaseflip_mean;
slice_phaseflip_rms = sqrt(mean(slice_phaseflip(:).^2));
slice_phaseflip = slice_phaseflip./slice_phaseflip_rms;

% projection_iCTF_mean = mean(projection_iCTF(:));
% projection_iCTF = projection_iCTF - projection_iCTF_mean;
% projection_iCTF_rms = sqrt(mean(projection_iCTF(:).^2));
% projection_iCTF = projection_iCTF./projection_iCTF_rms;

projection_iTCTF_mean = mean(projection_iTCTF(:));
projection_iTCTF = projection_iTCTF - projection_iTCTF_mean;
projection_iTCTF_rms = sqrt(mean(projection_iTCTF(:).^2));
projection_iTCTF = projection_iTCTF./projection_iTCTF_rms;

range = [-1 1.5];
dip_image(double(slice)'*255,'uint8')
dip_image((cut(slice_phaseflip(:,:,1),[N/2 N/2])-range(1))/diff(range)*255,'uint8')
% dip_image((cut(projection_iCTF(:,:,1),[N/2 N/2])-range(1))/diff(range)*255,'uint8')
dip_image((cut(projection_iTCTF(:,:,1),[N/2 N/2])-range(1))/diff(range)*255,'uint8')
dip_image((cut(projection_iTCTF(:,:,1)-slice_phaseflip(:,:,1),[N/2 N/2])-range(1))/diff(range)*255,'uint8')

writeim(dip_image((cut(slice_phaseflip(:,:,1),[N/2 N/2])-range(1))/diff(range)*255,'uint8'),'globalLocal_imod.tiff','tiff',0)
writeim(dip_image((cut(projection_iTCTF(:,:,1),[N/2 N/2])-range(1))/diff(range)*255,'uint8'),'globalLocal_TCTF.tiff','tiff',0)
writeim(dip_image((cut(projection_iTCTF(:,:,1)-slice_phaseflip(:,:,1),[N/2 N/2])-range(1))/diff(range)*255,'uint8'),'globalLocal_diff.tiff','tiff',0)

writeim(dip_image(double(slice)'*255,'uint8'),'globalLocal_slice.tiff','tiff',0)


%%
% qx = xx(N,1,'freq');
% qy = yy(1,N,'freq');
% 
% q2 = qx^2 + qy^2;
% 
% p2 = q2*N^2/params.fov^2;
% W0 = -pi*params.lambda*params.df_estimated*p2 + pi/2*params.C_s*params.lambda^3*p2.^2;
% cut(real(ift(sin(W0))),[128 128])

