% 1D projections
clear;

% define some constants
N = 4096;         % size of slice
Npart = 50;         % size of particle slice
particle_r = 5;   % size of particle
sigma = 0.7;      % blurring of particle

tiltAngle = 70/180*pi;
nangles = 71;     % number of angles

% the microscope parameters
params.C_s           = 2e-3;
params.df_estimated  = 1e-6;
params.lambda        = 2.5e-12;
params.fov           = 1065e-9;

pixelpitch = params.fov/N;

% create spherical test particle
particle = 38*(-erfclip(rr(Npart,Npart),particle_r,sigma)+particle_r + sigma/2)/sigma;

% allocate slice
slice=newim(N, N);

% fill slice with particles at three locations
locs = {[2023,2023],[100,2023],[2023 2984]};

d1 = abs(locs{1}-locs{2})*pixelpitch;
d2 = abs(locs{1}-locs{3})*pixelpitch;

nparticles = length(locs);
for k = 1:nparticles
    xloc = locs{k}(1);
    yloc = locs{k}(2);
    slice(xloc:xloc+Npart-1,yloc:yloc+Npart-1)=slice(xloc:xloc+Npart-1,yloc:yloc+Npart-1)+particle;
end
clear particle xloc yloc k margin nparticles particle_r sigma

% the angles of the tilt-series
angles = linspace(-tiltAngle,tiltAngle,nangles);

% simulate projections
sinogram = CTF_TiltThick_1d(slice,angles,params);
sinogram_noCTF = FreqDomRadon_1d(slice,angles);

% correction part
b = 0.2;
slice_mWedge = real(iFreqDomRadon_1d(sinogram_noCTF,angles));
slice_noCTF = real(iFreqDomRadon_1d(sinogram,angles));
slice_iCTF = real(iFreqDomRadon_1d(iCTF_Regular_1d(sinogram,params,'Wiener',7,b),angles));
slice_iTCTF = real(iFreqDomRadon_1d(iCTF_Tilt_1d(sinogram,angles,params,'Wiener',7,b),angles));
slice_i3DCTF = real(iCTF_TiltThick_1d(sinogram,angles,params,'Wiener',7,b));

%%% for comparison Tikhonov
sinogram_iTCTF_Tik = iCTF_Tilt_Tikhonov_1d(sinogram,angles,params,b);
sinogram_iTCTF_Tik = sinogram_iTCTF_Tik(end:-1:0,:);
slice_iTCTF_Tik = real(iFreqDomRadon_1d(sinogram_iTCTF_Tik,angles));

%%% for comparison real-space
slice_i3DCTF_real2 = iCTF_TiltThick_realspace_1d(sinogram,angles,params,'Wiener',7,b);
slice_i3DCTF_real2 = slice_i3DCTF_real2(:,end:-1:0);

lowt =  -3429751144.1964;
hight =  4056254402.8189;
stretchthis = @(slice) dip_image(255*(slice-lowt)/(hight-lowt),'uint8');
writethis   = @(slice,filename,locs) writeim(stretchthis(showthis(slice,locs)),filename,'TIFF',0);
showthis    = @(slice,locs) slice(locs(1)-Npart/2:locs(1)+1.5*Npart-1,locs(2)-Npart/2:locs(2)+1.5*Npart-1);

% writeim(dip_image(stretch(showthis(slice,locs{1}),0,100,0,255),'uint8'),'slice_1.tiff','TIFF',0)
writeim(dip_image(stretch(showthis(slice_mWedge,locs{1})),'uint8'),'slicemWedge_1.tiff','TIFF',0)
writeim(dip_image(stretch(showthis(slice_mWedge,locs{2})),'uint8'),'slicemWedge_2.tiff','TIFF',0)
writeim(dip_image(stretch(showthis(slice_mWedge,locs{3})),'uint8'),'slicemWedge_3.tiff','TIFF',0)
writethis(slice_mWedge,'slicemWedge_1.tiff',locs{1})
writethis(slice_mWedge,'slicemWedge_2.tiff',locs{2})
writethis(slice_mWedge,'slicemWedge_3.tiff',locs{3})
% writethis(slice_noCTF,'slicenoCTF_1.tiff',locs{1})
% writethis(slice_noCTF,'slicenoCTF_2.tiff',locs{2})
% writethis(slice_noCTF,'slicenoCTF_3.tiff',locs{3})
% writethis(slice_iCTF,'sliceICTF_wiener_1.tiff',locs{1})
% writethis(slice_iCTF,'sliceICTF_wiener_2.tiff',locs{2})
% writethis(slice_iCTF,'sliceICTF_wiener_3.tiff',locs{3})
% writethis(slice_iTCTF,'sliceITCTF_wiener_1.tiff',locs{1})
% writethis(slice_iTCTF,'sliceITCTF_wiener_2.tiff',locs{2})
% writethis(slice_iTCTF,'sliceITCTF_wiener_3.tiff',locs{3})
% writethis(slice_i3DCTF,'sliceI3DCTF_wiener_1.tiff',locs{1})
% writethis(slice_i3DCTF,'sliceI3DCTF_wiener_2.tiff',locs{2})
% writethis(slice_i3DCTF,'sliceI3DCTF_wiener_3.tiff',locs{3})
dipshow((showthis(slice,locs{1})),'lin')
dipshow(showthis(slice_mWedge,locs{1}),'lin')
dipshow(showthis(slice_mWedge,locs{2}),'lin')
dipshow(stretchthis(showthis(slice_mWedge,locs{3})),'lin')
dipshow((showthis(slice_noCTF,locs{1})),'lin')
dipshow((showthis(slice_noCTF,locs{2})),'lin')
dipshow((showthis(slice_noCTF,locs{3})),'lin')
dipshow((showthis(slice_iCTF,locs{1})),'lin')
dipshow((showthis(slice_iCTF,locs{2})),'lin')
dipshow((showthis(slice_iCTF,locs{3})),'lin')
dipshow((showthis(slice_iTCTF,locs{1})),'lin')
dipshow((showthis(slice_iTCTF,locs{2})),'lin')
dipshow((showthis(slice_iTCTF,locs{3})),'lin')
dipshow((showthis(slice_i3DCTF,locs{1})),'lin')
dipshow((showthis(slice_i3DCTF,locs{2})),'lin')
dipshow(stretchthis(showthis(slice_i3DCTF,locs{3})),'lin')

% dipshow((showthis(slice_iTCTF_Tik,locs{1})),'lin')
% dipshow((showthis(slice_iTCTF_Tik,locs{2})),'lin')
% dipshow((showthis(slice_iTCTF_Tik,locs{3})),'lin')
% dipshow((showthis(slice_i3DCTF_real2,locs{1})),'lin')
% dipshow((showthis(slice_i3DCTF_real2,locs{2})),'lin')
% dipshow((showthis(slice_i3DCTF_real2,locs{3})),'lin')

%% Difference between iTCTF and TCTF2
% 1D projections
clear;

% define some constants
N = 4096;         % size of slice
Npart=200;         % size of particle slice
particle_r = 20;   % size of particle
sigma = 0.7;      % blurring of particle

tiltAngle     = 70/180*pi;
nangles = 140;    % number of angles

% the microscope parameters
params.C_s           = 2e-3;
params.df_estimated  = 1e-6;
params.lambda        = 2.5e-12;
params.fov           = 266e-9;

pixelpitch = params.fov/N;

% create spherical test particle
particle = 38*(-erfclip(rr(Npart,Npart),particle_r,sigma)+particle_r + sigma/2)/sigma;

% allocate slice
slice=newim(N, N);

% fill slice with particles at random locations
locs = {[(N-Npart)/2,(N-Npart)/2]};

nparticles = length(locs);
for k = 1:nparticles
    xloc = locs{k}(1);
    yloc = locs{k}(2);
    slice(xloc:xloc+Npart-1,yloc:yloc+Npart-1)=slice(xloc:xloc+Npart-1,yloc:yloc+Npart-1)+particle;
end
clear particle xloc yloc k particle_r nparticles sigma

% the angles of the tilt-series
angles = linspace(-tiltAngle,tiltAngle,nangles);

% simulate projections
sinogram = CTF_TiltThick_1d(slice,angles,params);

slice_iTCTF = real(iFreqDomRadon_1d(iCTF_Tilt_1d(sinogram,angles,params,'CTF',1),angles));
slice_TCTF2 = 1/4*real(iFreqDomRadon_1d(CTF_Tilt_1d(sinogram,angles,params),angles));
% slice_iTCTF_strip = real(iFreqDomRadon_1d(iCTF_Tilt_strip_1d(sinogram,angles,params,'CTF',1),angles));

% lowt = -2126565990.8496;
% hight = 1303339730.3015;
% stretchthis = @(slice) dip_image(255*(slice-lowt)/(hight-lowt),'uint8');
showthis    = @(slice,locs) slice(locs(1)-Npart/2:locs(1)+1.5*Npart-1,locs(2)-Npart/2:locs(2)+1.5*Npart-1);
cropthis    = @(slice) cut(slice,size(slice)/4);
% writethis   = @(slice,filename,locs) writeim(stretchthis(cropthis(showthis(slice,locs))),filename,'TIFF',0);

cropthis(showthis(slice_iTCTF,locs{1}))
cropthis(showthis(slice_TCTF2,locs{1}))
% cropthis(showthis(slice_iTCTF_strip,locs{1}))
% writethis(slice_iTCTF,'sliceITCTF_CTF_1_crop.tiff',locs{1})
% writethis(slice_TCTF2,'sliceTCTF2_CTF_1_crop.tiff',locs{1})

xcoor = Npart/4+1+linspace(-Npart/4*cos(tiltAngle),Npart/4*cos(tiltAngle),Npart*2);
ycoor = Npart/4+1+linspace(-Npart/4*sin(tiltAngle),Npart/4*sin(tiltAngle),Npart*2);
iTCTF_profile = interp2(double(cropthis(showthis(slice_iTCTF,locs{1}))),xcoor,ycoor);
TCTF2_profile = interp2(double(cropthis(showthis(slice_TCTF2,locs{1}))),xcoor,ycoor);

plotrange = linspace(-pixelpitch*Npart/4,pixelpitch*Npart/4,Npart*2)*1e9;
plot(plotrange,iTCTF_profile,'k');
hold on;
plot(plotrange,TCTF2_profile,'r');

%% different filters
clear;
close all;

clear;

% define some constants
N = 4096;         % size of slice
Npart=200;         % size of particle slice
particle_r = 20;   % size of particle
sigma = 0.7;      % blurring of particle

tiltAngle     = 70/180*pi;
nangles = 140;    % number of angles

% the microscope parameters
params.C_s           = 2e-3;
params.df_estimated  = 1e-6;
params.lambda        = 2.5e-12;
params.fov           = 266e-9;

pixelpitch = params.fov/N;

% create spherical test particle
particle = 38*(-erfclip(rr(Npart,Npart),particle_r,sigma)+particle_r + sigma/2)/sigma;

% allocate slice
slice=newim(N, N);

% fill slice with particles at random locations
locs = {[(N-Npart)/2,(N-Npart)/2]};

nparticles = length(locs);
for k = 1:nparticles
    xloc = locs{k}(1);
    yloc = locs{k}(2);
    slice(xloc:xloc+Npart-1,yloc:yloc+Npart-1)=slice(xloc:xloc+Npart-1,yloc:yloc+Npart-1)+particle;
end
clear particle xloc yloc k particle_r sigma nparticles

% the angles of the tilt-series
angles = linspace(-tiltAngle,tiltAngle,nangles);

% simulate projections
sinogram = CTF_TiltThick_1d(slice,angles,params);

b = 0.5;
norders = 7;
slice_iCTF = real(iFreqDomRadon_1d(iCTF_Tilt_1d(sinogram,angles,params,'CTF',norders),angles));
slice_iPhase = real(iFreqDomRadon_1d(iCTF_Tilt_1d(sinogram,angles,params,'Phase',norders),angles));
slice_iWiener = real(iFreqDomRadon_1d(iCTF_Tilt_1d(sinogram,angles,params,'Wiener',norders,b),angles));

stretchthis = @(slice) dip_image(stretch(slice),'uint8');
showthis    = @(slice,locs) slice(locs(1)-Npart/2:locs(1)+1.5*Npart-1,locs(2)-Npart/2:locs(2)+1.5*Npart-1);
cropthis    = @(slice) cut(slice,size(slice)/4);
% writethis   = @(slice,filename,locs) writeim(stretchthis(cropthis(showthis(slice,locs))),filename,'TIFF',0);

% writethis(slice_iCTF,'sliceFilter_CTF.tiff',locs{1})
% writethis(slice_iPhase,'sliceFilter_Phase.tiff',locs{1})
% writethis(slice_iWiener_high,'sliceFilter_Wiener.tiff',locs{1})
stretchthis(cropthis(showthis(slice_iCTF,locs{1})))
stretchthis(cropthis(showthis(slice_iPhase,locs{1})))
stretchthis(cropthis(showthis(slice_iWiener,locs{1})))


xcoor = Npart/4+1+linspace(-Npart/4*cos(tiltAngle),Npart/4*cos(tiltAngle),Npart*2);
ycoor = Npart/4+1+linspace(-Npart/4*sin(tiltAngle),Npart/4*sin(tiltAngle),Npart*2);

CTF_profile = interp2(double(cropthis(showthis(slice_iCTF,locs{1}))),xcoor,ycoor);
phase_profile = interp2(double(cropthis(showthis(slice_iPhase,locs{1}))),xcoor,ycoor);
wiener_profile = interp2(double(cropthis(showthis(slice_iWiener,locs{1}))),xcoor,ycoor);

plotrange = linspace(-pixelpitch*Npart/4,pixelpitch*Npart/4,Npart*2)*1e9;
figure; 
hold on; 
plot(plotrange,CTF_profile*2/(CTF_profile(Npart)+CTF_profile(Npart+1)),'k');
plot(plotrange,phase_profile*2/(phase_profile(Npart)+phase_profile(Npart+1)),'r');
plot(plotrange,wiener_profile*2/(wiener_profile(Npart)+wiener_profile(Npart+1)),'b');


qx = xx(N,1,'freq');
p  = qx*N/params.fov;
W0 = -pi*params.lambda*params.df_estimated*p.^2 + pi/2*params.C_s*params.lambda^3*p.^4;
filterCTF = getFilter(W0,'CTF',0,norders);
filterPhase = getFilter(W0,'Phase',0,norders);
filterWiener = getFilter(W0,'Wiener',b,norders);

stretchRMS = @(f) f./sqrt(mean(f(:).^2));

plotrange = double(p)*1e-9;
figure; 
hold on; 
plot(plotrange,-stretchRMS(double(filterCTF)),'k');
plot(plotrange,-stretchRMS(double(filterPhase)),'r');
plot(plotrange,-stretchRMS(double(filterWiener)),'b');
axis([0 1.5 -1.9 1.9])

%% more elaborate sample
% 1D projections
clear;

% define some constants
N = 4096;         % size of slice
tiltAngle = 70/180*pi;
nangles = 561;     % number of angles

% the microscope parameters
params.C_s           = 2e-3;
params.df_estimated  = 1e-6;
params.lambda        = 2.5e-12;
params.fov           = 1065e-9;

pixelpitch = params.fov/N;

% allocate slice
slice=newim(N, N);

% particlers = [5 15 30 60];
% circlerr = {[1900 1200 600 300],[1800 1300 1100 700 500 200],[1700 800 400],[1500 0]};
particlers = [5 15 30 60];
circlerr = {[1900 1200 600 120],[1800 1300 1100 500 200],[1700 400],[1500 0]};
startangle = {[0.7 0.1 0.4 0.6],[0.5 0.2 0.7 0.1 0.3],[0.9 0.1],[0.05 0]};

bilayert = round(3.5e-9/pixelpitch);
bilayerlayert = 1.5;
sigmabilayer = 1;

for n = 1:length(particlers)
    % create spherical test particle
    particle_r = particlers(n);   % size of particle
    Npart = 4*particle_r; % size of particle slice
    sigma = 0.7;      % blurring of particle
    if particle_r <= bilayert/2
        particle = 38*(-erfclip(rr(Npart,Npart),particle_r,sigma)+particle_r + sigma/2)/sigma;
    elseif particle_r <= bilayert
        particle = 38*(-erfclip(abs(rr(Npart,Npart)-particle_r),bilayerlayert,sigmabilayer)+bilayerlayert+sigmabilayer/2)/sigmabilayer;
    else
        particle = 38*(-erfclip(abs(rr(Npart,Npart)-particle_r),bilayerlayert,sigmabilayer)+bilayerlayert+sigmabilayer/2)/sigmabilayer + 38*(-erfclip(abs(rr(Npart,Npart)-particle_r-bilayert),bilayerlayert,sigmabilayer)+bilayerlayert+sigmabilayer/2)/sigmabilayer;
    end
    circler = circlerr{n};
    pixperparticle = 35*sqrt(5*particle_r);
    for m = 1:length(circler)
        nparticles = max(1,round(2*pi*circler(m)./pixperparticle));
        particlealpha = startangle{n}(m)*2*pi/nparticles:2*pi/nparticles:2*pi;
        for k = 1:nparticles
            xloc = round(N/2+circler(m)*cos(particlealpha(k))-Npart/2);
            yloc = round(N/2+circler(m)*sin(particlealpha(k))-Npart/2);
%             if yloc-N/2 < -1280 || yloc-N/2 > 1.1*pixperparticle
%                 continue
%             end
            slice(xloc:xloc+Npart-1,yloc:yloc+Npart-1)=slice(xloc:xloc+Npart-1,yloc:yloc+Npart-1)+particle;
        end
    end
end
clear particle xloc yloc k margin nparticles particle_r sigma particlealpha particlers pixperparticle circler circlerr m n

% slightly modify the spatial frequency content.
sliceHFmean = double(radialmean(abs(ft(slice)),[],1,1));
slicerr = rr(slice);
slicerr = double(slicerr(:));
sliceHFmean_rr = interp1(0:N/2,sliceHFmean,slicerr);
sliceHFmean_rr = reshape(sliceHFmean_rr,[N N]);
sliceHFnorm_rr = 1./sliceHFmean_rr;

sigma = 0.7;
gaussmask = real(ft(gaussf(rr(slice)==0,sigma)));
gaussmask = gaussmask./max(gaussmask);

sliceHFnorm_rr(isnan(sliceHFnorm_rr)) = 0;
sliceHFnorm_rr(N/2,N/2) = 1;
sliceHFnorm_rr = (sliceHFnorm_rr + 1)/2;
slice = real(ift(ft(slice)*sliceHFnorm_rr*gaussmask));
% sum(slice<0)/(N^2)
% slice(slice<0) = 0;


% the angles of the tilt-series
angles = linspace(-tiltAngle,tiltAngle,nangles);

% simulate projections
sinogram = CTF_TiltThick_1d(slice,angles,params);

SNR = 5;
rms = @(x) sqrt(mean(x(:).^2));
sinogram_nonoise = sinogram;
sinogram = noise(sinogram_nonoise,'gaussian',rms(sinogram)/SNR);

% correction part
b = 0.075;
norders = 30;
method = 'Wiener';
% b = 0.15;
% norders = 20;
slice_noCTF = real(iFreqDomRadon_1d(sinogram,angles));
slice_iCTF = real(iFreqDomRadon_1d(iCTF_Regular_1d(sinogram,params,method,norders,b),angles));
slice_iTCTF = real(iFreqDomRadon_1d(iCTF_Tilt_1d(sinogram,angles,params,method,norders,b),angles));
slice_i3DCTF = real(iCTF_TiltThick_1d(sinogram,angles,params,method,norders,b));

lowt =  -6e9;
hight =  5e9;
lowt =  -2e9;
hight =  2.5e9;
% lowt =  -1e9;
% hight =  1.5e9;
stretchthis = @(slice) dip_image(255*(slice-lowt)/(hight-lowt),'uint8');
stretchslice = @(slice) dip_image(255*slice/(0.8*max(slice)),'uint8');
cropthis    = @(slice,locs,Ncrop) slice(locs(1):locs(1)+Ncrop-1,locs(2):locs(2)+Ncrop-1);
% writethis   = @(slice,filename,locs,cropN) writeim(stretchthis(rebin(cropthis(slice,locs,cropN),2)/4),filename,'TIFF',0);
writethis   = @(slice,filename,locs,cropN) writeim(stretchthis(cropthis(slice,locs,cropN)),filename,'TIFF',0);
writeslice   = @(slice,filename,locs,cropN) writeim(stretchslice(cropthis(slice,locs,cropN)),filename,'TIFF',0);

cropN = 512;
croploc = {[N/2-cropN/2,N/2-cropN/2],[125 1650],[900 850]};

stretchthis(cropthis(slice_noCTF,croploc{1},cropN))
stretchthis(cropthis(slice_iCTF,croploc{1},cropN))
stretchthis(cropthis(slice_iTCTF,croploc{1},cropN))
stretchthis(cropthis(slice_i3DCTF,croploc{1},cropN))
stretchthis(cropthis(slice_noCTF,croploc{2},cropN))
stretchthis(cropthis(slice_iCTF,croploc{2},cropN))
stretchthis(cropthis(slice_iTCTF,croploc{2},cropN))
stretchthis(cropthis(slice_i3DCTF,croploc{2},cropN))
stretchthis(cropthis(slice_noCTF,croploc{3},cropN))
stretchthis(cropthis(slice_iCTF,croploc{3},cropN))
stretchthis(cropthis(slice_iTCTF,croploc{3},cropN))
stretchthis(cropthis(slice_i3DCTF,croploc{3},cropN))
stretchslice(cropthis(slice,croploc{1},cropN))
stretchslice(cropthis(slice,croploc{2},cropN))
stretchslice(cropthis(slice,croploc{3},cropN))

% stretchthis(rebin(cropthis(slice_noCTF,croploc{1},cropN),2)/4)
% stretchthis(rebin(cropthis(slice_iCTF,croploc{1},cropN),2)/4)
% stretchthis(rebin(cropthis(slice_iTCTF,croploc{1},cropN),2)/4)
% stretchthis(rebin(cropthis(slice_i3DCTF,croploc{1},cropN),2)/4)
% stretchthis(rebin(cropthis(slice_noCTF,croploc{2},cropN),2)/4)
% stretchthis(rebin(cropthis(slice_iCTF,croploc{2},cropN),2)/4)
% stretchthis(rebin(cropthis(slice_iTCTF,croploc{2},cropN),2)/4)
% stretchthis(rebin(cropthis(slice_i3DCTF,croploc{2},cropN),2)/4)
% stretchthis(rebin(cropthis(slice_noCTF,croploc{3},cropN),2)/4)
% stretchthis(rebin(cropthis(slice_iCTF,croploc{3},cropN),2)/4)
% stretchthis(rebin(cropthis(slice_iTCTF,croploc{3},cropN),2)/4)
% stretchthis(rebin(cropthis(slice_i3DCTF,croploc{3},cropN),2)/4)
% stretchslice(rebin(cropthis(slice,croploc{1},cropN),2)/4)
% stretchslice(rebin(cropthis(slice,croploc{2},cropN),2)/4)
% stretchslice(rebin(cropthis(slice,croploc{3},cropN),2)/4)

writethis(slice_noCTF,'orbit_1_noCTF.tiff',croploc{1},cropN)
writethis(slice_iCTF,'orbit_1_CTF.tiff',croploc{1},cropN)
writethis(slice_iTCTF,'orbit_1_TCTF.tiff',croploc{1},cropN)
writethis(slice_i3DCTF,'orbit_1_3DCTF.tiff',croploc{1},cropN)
writethis(slice_noCTF,'orbit_2_noCTF.tiff',croploc{2},cropN)
writethis(slice_iCTF,'orbit_2_CTF.tiff',croploc{2},cropN)
writethis(slice_iTCTF,'orbit_2_TCTF.tiff',croploc{2},cropN)
writethis(slice_i3DCTF,'orbit_2_3DCTF.tiff',croploc{2},cropN)
writethis(slice_noCTF,'orbit_3_noCTF.tiff',croploc{3},cropN)
writethis(slice_iCTF,'orbit_3_CTF.tiff',croploc{3},cropN)
writethis(slice_iTCTF,'orbit_3_TCTF.tiff',croploc{3},cropN)
writethis(slice_i3DCTF,'orbit_3_3DCTF.tiff',croploc{3},cropN)

writeslice(slice,'orbit_1_slice.tiff',croploc{1},cropN)
writeslice(slice,'orbit_2_slice.tiff',croploc{2},cropN)
writeslice(slice,'orbit_3_slice.tiff',croploc{3},cropN)

writeim(stretchslice(rebin(slice,4)),'orbit_slice.tiff','TIFF',0);

%SCALEBAR:
% cropN*pixelpitch*1e9 % size of cropped window in nm
scalebarlength = 50; %in nm
scalebarpix = round(scalebarlength*1e-9/pixelpitch);

crop = newim(cropN,cropN);
crop(0:scalebarpix-1,0:scalebarpix-1) = 1;
writeim(dip_image(crop*255,'uint8'),'orbit_scalebar.tiff','tiff',0);
