clear;
close all;

Ns = [1024 2048 4096];
norderss = [4 8];
niter = 100;
timings = zeros(6,length(norderss),length(Ns),niter);

i = 1;
for i = i:niter
    for Ni = 1:length(Ns)
        N = Ns(Ni);         % size of slice

        % define some constants
        Npart=50;         % size of particle slice
        margin = 100;
        particle_r = 5;   % size of particle
        sigma = 0.7;      % blurring of particle

        nangles = 141;    % number of angles

        % the microscope parameters
        params.C_s           = 2e-3;
        params.df_estimated  = 1e-6;
        params.lambda        = 2.5e-12;
        params.fov           = 1065e-9;
        params.tiltAngle     = 70/180*pi;

        pixelpitch = params.fov/N;

        % create spherical test particle
        particle = 38*(-erfclip(rr(Npart,Npart),particle_r,sigma)+particle_r + sigma/2)/sigma;

        % allocate slice
        slice=newim(N, N);

        % fill slice with particles at random locations
        locs = {round([(N-Npart)/2,(N-Npart)/2]),...
                round([margin,(N-Npart)/2]),...
                round([(N-Npart)/2,(N-Npart)/4])};

        nparticles = length(locs);
        for k = 1:nparticles
            xloc = locs{k}(1);
            yloc = locs{k}(2);
            slice(xloc:xloc+Npart-1,yloc:yloc+Npart-1)=slice(xloc:xloc+Npart-1,yloc:yloc+Npart-1)+particle;
        end
        clear particle xloc yloc k

        % the angles of the tilt-series
        angles = linspace(-params.tiltAngle,params.tiltAngle,nangles);

        % simulate projections
        sinogram = CTF_TiltThick_1d(slice,angles,params);

        % correction part
        b = 0.5;
        norders = norderss(1);
        
        [i N]
        
        tic; sinogram_iCTF = iCTF_Regular_1d(sinogram,params,'Wiener',norders,b);
        timings(1,1,Ni,i) = toc; 
        
        tic; sinogram_iTCTF_Tik = iCTF_Tilt_Tikhonov_1d(sinogram,angles,params,b);
        timings(3,1,Ni,i) = toc;
        
        tic; slice_iCTF = iFreqDomRadon_1d(sinogram_iCTF,angles);
        timings(4,1,Ni,i) = toc;       
        
        tic; slice_i3DCTF_real  = iCTF_TiltThick_realspace_1d(sinogram,angles,params,'Wiener',norders,b);
        timings(6,1,Ni,i) = toc;
        for nordersi = 1:length(norderss)
            norders = norderss(nordersi);
            
            [i norders N]
            
            tic; sinogram_iTCTF = iCTF_Tilt_1d(sinogram,angles,params,'Wiener',norders,b);
            timings(2,nordersi,Ni,i) = toc;

            tic; slice_i3DCTF = iCTF_TiltThick_1d(sinogram,angles,params,'Wiener',norders,b);
            timings(5,nordersi,Ni,i) = toc;
        end
    end
end
i=i+1;

printtiming = @(str,timings,Ns) {
fprintf('\n%s\n',str);...
fprintf('%10i    \t',Ns);fprintf('\n');
fprintf('%10.2f (m)\t',squeeze(mean(timings,4))'.*Ns/60);fprintf('\n');
fprintf('%10.2f (h)\t',squeeze(mean(timings,4))'.*Ns/60/60);fprintf('\n');
fprintf('%10.2f (d)\t',squeeze(mean(timings,4))'.*Ns/60/60/24);fprintf('\n');
fprintf('  %10.4f%% \t',squeeze(mean(timings,4))'.*Ns/60/60/24);fprintf('standard dev.\n');
};

printtiming('iCTF_Regular_1d',timings(1,1,:,1:i-1),Ns);
printtiming('iCTF_Tilt_1d, N=7',timings(2,1,:,1:i-1),Ns);
printtiming('iCTF_Tilt_1d, N=15',timings(2,2,:,1:i-1),Ns);
printtiming('iCTF_Tilt_Tikhonov_1d',timings(3,1,:,1:i-1),Ns);
printtiming('iFreqDomRadon_1d',timings(4,1,:,1:i-1),Ns);
printtiming('iCTF_TiltThick_1d, N=7',timings(5,1,:,1:i-1),Ns);
printtiming('iCTF_TiltThick_1d, N=15',timings(5,2,:,1:i-1),Ns);
printtiming('iCTF_TiltThick_realspace_1d',timings(6,1,:,1:i-1),Ns);
