function stack = CTF_Regular_2d(stack,params)
%CTF_REGULAR_2D   Compute Regular CTF for 2D projection
%
%
% SYNOPSIS:
%  stack = CTF_REGULAR_2D(stack,params);
% 
% PARAMETERS:
%  stack:      Input stack (xp,angles,yp)
%  params:     Set of microscope and acquisition parameters
% 
% OUTPUT:
%  stack:   


% The Quantitative Imaging Group of the TU Delft has developed and is the 
% owner of the image processing routines distributed in this package, 
% hereafter called SOFTWARE.
% 
% The SOFTWARE is free for non-commercial use by students and staff in 
% universities or non-profit research institutes.
% 
% Redistribution of SOFTWARE or parts thereof in any form is not permitted.
% 
% This SOFTWARE is distributed in the hope that it will be useful, but 
% without any warranty; without even the implied warranty of 
% merchantability or fitness for a particular purpose.

stack = dip_image(stack);

if ndims(stack) ~= 3
    error('stack should be 3D');
end

Ny = size(stack,3);
qy = yy(1,Ny,'freq');

% FT in y direction
stack = dip_fouriertransform(stack,'forward',[0 0 1]);

% iterate over y
for k = 0:Ny-1
    sinogram = squeeze(stack(:,:,k));
    
    sinogram = CTF_Regular_2d_sinogram(sinogram,qy(0,k),params);
    
    stack(:,:,k) = sinogram;
end

% IFT in y direction
stack = real(dip_fouriertransform(stack,'inverse',[0 0 1]));
