function sinogram = CTF_Regular_2d_sinogram(sinogram,qy,params)
%CTF_REGULAR_2D_SINOGRAM   Compute Regular CTF for 2D projection
%
%
% SYNOPSIS:
%  sinogram = CTF_REGULAR_2D_SINOGRAM(sinogram,qy,params);
% 
% PARAMETERS:
%  sinogram:   Input projections (xp,angles)
%  qy:         Value of q_y for this slice
%  params:     set of microscope and acquisition parameters
% 
% OUTPUT:
%  sinogram:   

% The Quantitative Imaging Group of the TU Delft has developed and is the 
% owner of the image processing routines distributed in this package, 
% hereafter called SOFTWARE.
% 
% The SOFTWARE is free for non-commercial use by students and staff in 
% universities or non-profit research institutes.
% 
% Redistribution of SOFTWARE or parts thereof in any form is not permitted.
% 
% This SOFTWARE is distributed in the hope that it will be useful, but 
% without any warranty; without even the implied warranty of 
% merchantability or fitness for a particular purpose.

sinogram = dip_image(sinogram);
N = size(sinogram,1);

qx = xx(N,1,'freq');
q2 = qx^2 + qy^2;

sinogram = dip_fouriertransform(sinogram,'forward',[1 0]);

p2 = q2*N^2/params.fov^2;
W0 = -pi*params.lambda*params.df_estimated*p2 + pi/2*params.C_s*params.lambda^3*p2.^2;

sinogram = 2*sin(W0)*sinogram;

%inverse fourier transform
sinogram = dip_fouriertransform(sinogram,'inverse',[1 0]);
