function sinogram = CTF_TiltThick_1d(slice,angles,params)
%CTF_TILTTHICK_1D   Compute Tilt+Thick CTF for 1D projections of Slice
%
%
% SYNOPSIS:
%  sinogram = CTF_TILTTHICK_1D(slice,angles,params);
% 
% PARAMETERS:
%  slice:   Input slice (x,z)
%  angles:  Angles at which to compute the projections
%  params:     set of microscope and acquisition parameters
% 
% OUTPUT:
%  sinogram: 

% The Quantitative Imaging Group of the TU Delft has developed and is the 
% owner of the image processing routines distributed in this package, 
% hereafter called SOFTWARE.
% 
% The SOFTWARE is free for non-commercial use by students and staff in 
% universities or non-profit research institutes.
% 
% Redistribution of SOFTWARE or parts thereof in any form is not permitted.
% 
% This SOFTWARE is distributed in the hope that it will be useful, but 
% without any warranty; without even the implied warranty of 
% merchantability or fitness for a particular purpose.

% make sure input is dip_image
slice = dip_image(slice);

% a needs to be square:
slice = extend(slice,[max(size(slice)) max(size(slice))]);

N = size(slice,1);

% create set of frequency points
qx = double(xx(N,1,'freq'));
qz = 1/2*params.lambda*qx.^2*N/params.fov;

q = zeros(2,2*N*length(angles));

for t = 1:length(angles);
    R = [cos(angles(t)) sin(angles(t));-sin(angles(t)) cos(angles(t))];
    
    q(:,(2*t-2)*N+1:(2*t-1)*N) = R*[qx;  -qz];
    q(:,(2*t-1)*N+1:2*t*N)     = R*[qx; qz];
end
q = dip_image(q);

% compute NUFFT
sinogram = nufft_type2(slice,im2array(q));
sinogram = reshape(sinogram,[N 2*length(angles)]);

qx = xx(N,1,'freq');
p  = qx*N/params.fov;
W0 = -pi*params.lambda*params.df_estimated*p.^2 + pi/2*params.C_s*params.lambda^3*p.^4;

sinogram = 1i*exp(-1i*W0).*sinogram( : , 0:2:end )-1i*exp(1i*W0).*sinogram( : , 1:2:end );

%inverse fourier transform
sinogram = real(dip_fouriertransform(sinogram,'inverse',[1 0]));
