function projection = CTF_Tilt_2d_projection(projection,angle,params)
%CTF_TILT_2D_PROJECTION   Compute Tilt CTF for 2D projection
%
%
% SYNOPSIS:
%  projection = CTF_TILT_2D_PROJECTION(projection,angle,params);
% 
% PARAMETERS:
%  projection: Input projection (xp,yp)
%  angle:      Angle of current projection
%  params:     set of microscope and acquisition parameters
% 
% OUTPUT:
%  projection:   

% The Quantitative Imaging Group of the TU Delft has developed and is the 
% owner of the image processing routines distributed in this package, 
% hereafter called SOFTWARE.
% 
% The SOFTWARE is free for non-commercial use by students and staff in 
% universities or non-profit research institutes.
% 
% Redistribution of SOFTWARE or parts thereof in any form is not permitted.
% 
% This SOFTWARE is distributed in the hope that it will be useful, but 
% without any warranty; without even the implied warranty of 
% merchantability or fitness for a particular purpose.

projection = dip_image(projection);

if size(projection,1) ~= size(projection,2)
    error('image must be square');
end

N = size(projection,1);

qx = xx(N,1,'freq');
qy = yy(1,N,'freq');

q2 = qx^2 + qy^2;


qxp = -1/2*params.lambda*q2*N/params.fov*tan(angle);
q = [qx + qxp  qx - qxp];

projection = nufft_type2(projection, q,[1 1],[1 0]);

p2 = q2*N^2/params.fov^2;
W0 = -pi*params.lambda*params.df_estimated*p2 + pi/2*params.C_s*params.lambda^3*p2.^2;

projection = 1i*exp(-1i*W0).*projection(0:N-1,:)-1i*exp(1i*W0).*projection(N:end,:);

%inverse fourier transform
projection = real(ift(projection));
